"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useLecomScan = exports.toggleScan = void 0;

var _reactNative = require("react-native");

var _react = require("react");

const {
  OS,
  constants
} = _reactNative.Platform;
var LecomEvents;

(function (LecomEvents) {
  LecomEvents["ScanSuccess"] = "EventLecomScanSuccess";
})(LecomEvents || (LecomEvents = {}));

const LINKING_ERROR = `The package 'react-native-lecom-scan' doesn't seem to be linked. Make sure you rebuilt the app after installing the package`;
const LecomScan = _reactNative.NativeModules.LecomScan ? _reactNative.NativeModules.LecomScan : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }

});
/**
 * Boolean value matches model and brand of Lecom T80 scacnner.
 */

const isLecom = OS === 'android' && constants.Brand === 'alps' && constants.Model === 'PDA';
/**
 * Emitter to listen to the 'EventLecomScanSuccess' event.
 */

const LecomScanEmitter = new _reactNative.NativeEventEmitter(LecomScan);
/**
 * Function used to initialize the scanner.
 */

const init = () => LecomScan.init();
/**
 * Function used to programmatically toggle scan mode.
 */


const toggleScan = () => LecomScan.toggleScan();
/**
 * (Android only) Hook used for the scanner integration.
 * Initializes the scanner and returns scanned code.
 *
 * @param options
 */


exports.toggleScan = toggleScan;

const useLecomScan = function () {
  let {
    callback,
    isActive = true
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  const [code, setCode] = (0, _react.useState)('');
  const isDevice = isLecom;

  const onScanSuccess = async c => {
    if (callback) await callback(c);
    setCode(c);
  };

  (0, _react.useEffect)(() => {
    if (isActive && isLecom) init();
    const subscription = LecomScanEmitter.addListener(LecomEvents.ScanSuccess, c => onScanSuccess(c));
    return () => subscription.remove();
  }, [isActive, isDevice]); // eslint-disable-line react-hooks/exhaustive-deps

  return {
    code,
    isDevice
  };
};

exports.useLecomScan = useLecomScan;
//# sourceMappingURL=index.android.js.map